/********************************************************************
** Likelihood Evaluation using Kalman Filter
**
** {loglh,retcode,obserror,obsvar} = evalmod(para,YY,msel);
** #include ****_mod.src,  to run this procedure
**
** Last updated: 06/16/2005 
********************************************************************/

/************************************************************************/

proc (1) = evalmod(para,YY,msel);

local loglh,retcode,obserror,obsvar,loglhzero,
      nobs,ny,nstate,tcond,
      TT,QQ,RR,HH,DD,ZZ,VV,
      t,At,Pt,At1,Pt1,Ft,alphahat,Phat,nut,yhat,
      th1, th2, th3, phi1, phi2, phi3, phie;

/** initialize **/
nobs = rows(YY);
ny   = cols(YY);

loglhzero = -1E8;

loglh     = 0;
retcode   = 0;
obserror  = zeros(nobs,ny);
obsvar    = zeros(nobs,ny);

th1 = para[1];
th2 = para[2];
th3 = para[3];

phi1 = th1^2;  
phi2 = 1-th1^2; 
phi3 = phi2 - th1*th2;
phie = th3;

TT = (phi1 ~ 0)|(phi3 ~ phi2);
ZZ = 1 ~ 1;
DD = 0;
RR = phie | 0;
QQ = 1;
HH = 0;
VV = 0; 

if maxc(abs(eig(TT))) > 1.001;
   /* system is unstable */
   retcode = 1;
   loglh = loglhzero;
   goto eofeval;
endif;


/**********************************************************
**      Likelihood evaluation by Kalman filter
**********************************************************/
nstate = rows(TT);

/** initial mean and variance for the state vector 
**/
At = zeros(nstate,1);
Pt = zeros(nstate,nstate);
tcond = 0;


t = 1;
do until t > 2000;
   Pt = TT*Pt*TT' + RR*QQ*RR';
   t = t+1;
endo;

/*
Pt = dlyap(TT,RR*QQ*RR');
*/

/** filter loop **/
t = 1;
do until t > nobs;

   At1 = At;
   Pt1 = Pt;

   /** Forecasting **/
   alphahat = TT*At1;
   Phat     = TT*Pt1*TT' + RR*QQ*RR';
   Phat     = .5*(Phat+Phat');

   yhat     = ZZ*alphahat + DD;
   nut      = YY[t,.] - yhat';
   
   Ft       = ZZ*Phat*ZZ' + HH + ZZ*RR*VV + (ZZ*RR*VV)';
   Ft       = .5*(Ft+Ft');
   
   
   /** to make likelihood comparable to VAR(tcond), condition on first tcond observations **/
   if t > tcond;
    loglh    =  loglh -0.5*cols(YY)*ln(2*pi) - 0.5*ln(det(Ft)) - 0.5*nut*inv(Ft)*nut';
   endif;

   /** Updating **/
   At = alphahat + Phat*ZZ'*inv(Ft)*nut';
   Pt = Phat - (Phat*ZZ'+RR*VV)*inv(Ft)*(Phat*ZZ'+RR*VV)';

   obserror[t,.] = nut;
   obsvar[t,.]   = diag(Ft)';
   
   t = t+1;
endo;

eofeval:

if ismiss(real(loglh))==1;
   loglh = loglhzero;
endif;



retp(real(loglh));
endp;
