/******************************************************************************
* 
******************************************************************************/
new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

#include ss_spec.g;
#include pathspec.g;

/********************************************************************
* Load Model Parameters
********************************************************************/

dgpstr    = "paradgp" $+ dataselstr $+ ".out";
para      = zeros(npara,1);
load path = ^priopath para[npara,1] = ^dgpstr;

th1_true = para[1];
th2_true = para[2];

/********************************************************************
* Load Likelihood Values
********************************************************************/

lpath  = parapath $+ "\\likegrid";
llike  = lpath $+ "\\like";

open fhlike = ^llike for read;

/** read first row **/
like_grid = readr(fhlike,1);

/** Initialization **/
eofloop = 0;
loopct  = 1;
nblock  = 20;

do until eofloop;

   /** Read blocks of size nblock **/
   like_read = readr(fhlike,nblock);
   if ismiss(like_read) == 0;
      like_grid = like_grid | like_read;
   endif;

   loopct = loopct + 1;
   eofloop = eof(fhlike);

endo;

closeall fhlike;

/** separate theta and like values **/

th1_xn = cols(like_grid)-1;
th2_xn = rows(like_grid)-1;

th1_xgrid = like_grid[th2_xn+1,1:th1_xn];
th2_xgrid = like_grid[1:th2_xn,th1_xn+1];

like_grid = like_grid[1:th2_xn,1:th1_xn];

/** normalize the likelihood function: max = 0 **/

like_grid = like_grid - maxc(maxc(like_grid));


graphset;
fonts("microb");
_ptitlht = 0.4;
_paxht = 0.3;
_pnumht = 0.3;
_pltype = {6 6 2}; 
_pcolor = {1 1};
_plwidth = 6.5;
_plctrl = 0;
_protate = 0;

begwind;
window(1,1,1);

ylabel("Theta 2");
xlabel("Theta 1");

xmin = 0;
xmax = 1;
xstep = 0.2;

ymin = 0;
ymax = 1;
ystep = 0.2;

ytics(ymin,ymax,ystep,2);
xtics(xmin,xmax,xstep,2);
ztics(-5,0,0.5,1); 

/*
xy(th1_xgrid',th2_uv~th2_lv);
*/

_pline = ( 1 ~ 6 ~ xmin ~ th2_true ~ xmax ~ th2_true ~ 0 ~ 4 ~ 7 ) |
         ( 1 ~ 6 ~ th1_true ~ ymin ~ th1_true ~ ymax ~ 0 ~ 4 ~ 7 ) ;

contour(th1_xgrid,th2_xgrid,like_grid); 

endwind;

end;


