/*************************************************************************
**  Simulate the state-space model 
**************************************************************************/

/* filename: ss_sim.g
** created:  
** Modifications:
**
*/

new;

/** set seed **/
rndseed 1234;

/****************************************************
* Housecleaning and set defaults
****************************************************/

library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

_fcmptol = 1E-10;

#include ss_spec.g
#include pathspec.g
   
/* Load model parameters
*/
dgpstr    = "paradgp" $+ dataselstr $+ ".out";
para      = zeros(npara,1);
load path = ^priopath para[npara,1] = ^dgpstr;

yt = sssim(para,msel,Tsimburn,Tsimtotal);

"Data Simulated Successfully";
"DGP Choice:          " datasel;
"Model Specification: " msel;
"Parameters (theta):  "; para;
"Mean of YT:          " meanc(yT)';
"StD of YT:           " stdc(yT)';

/********************************************************
** Save simulated data
*/

osimdata         = datapath $+ "\\" $+ lmodel $+ "sim" $+ dataselstr;
create fhsimdata = ^osimdata with SERIES, cols(yt), 8;
wr               = writer(fhsimdata,yT);
closeall fhsimdata;   

"Data saved";

/********************************************************
** procedure to simulated data
*/

proc(1) = sssim(para,msel,Tsimburn,Tsimtotal);
local th1, th2, th3, phi1, phi2, phi3, phie,
      TT, ZZ, RR, st, yt, t;

th1 = para[1];
th2 = para[2];
th3 = para[3];

phi1 = th1^2;   
phi2 = 1-th1^2; 
phi3 = phi2 - th1*th2;
phie = th3;

TT = (phi1 ~ 0)|(phi3 ~ phi2);
ZZ = 1 ~ 1;
RR = phie | 0;

st = zeros(2,1);
yt = zeros(Tsimtotal,1);

t = 1;
do until t > Tsimtotal;

   st = TT*st + RR*rndn(1,1);
   yt[t,.] = ZZ*st;
   t = t+1;
   
endo;

yt = yt[Tsimburn+1:Tsimtotal];

retp(yt);
endp;
