/* filename:    var_mddplot.g
** description: 
** created:     
*/

new;
/** set seed **/
/** rndseed 1234; **/

/********************************************************
* House cleaning and set defaults
********************************************************/
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

mhrun = "1";

/** Global defaults **/
__output = 1;       /** 1 for verbose of CSMIN**/
__graph  = 1;       /** 1 for graph mode **/
_verbose = 2;       /** 0 for silence, 1 for compact, 2 for detailed**/
_fcmptol = 1E-10;

/** only the following 2 lines are model dependent **/
#include dsge_spec.g;
#include var_spec.g;
#include pathspec.g;

/**** LOAD MARGINAL DATA DENSITIES ****/

/** set lambda-grid **/
lamgrid  =  101 | 50 | 10 | 5 | 2 | 1 | 0.75 | 0.5 | 0.3 | 0 ;
nlambda = rows(lamgrid);

/** set Tind **/
lsamp = "T01";

/** initialize marginal data densities **/
mddgrid = zeros(nlambda,1);

/** iterate over lambda grid **/
lamind = 1;
do until lamind > nlambda;

   lambda = lamgrid[lamind,1];
   llam = "L" $+ ftos(90000+10*lambda,"%*.*lf",5,0);

   lpath  = parapath $+ "\\mhrun" $+ mhrun;
   lmdd  = lpath $+ "\\" $+ llam $+ lsamp $+ "mhdd";

   open fhmdd = ^lmdd for read; 
   
   mddrow = readr(fhmdd,1);
   mddrow = mddrow[cols(mddrow)-17:cols(mddrow)-9];
   mddgrid[lamind] = meanc(mddrow');

   closeall;
   
   lamind = lamind+1;
   
endo;

mddgrid = mddgrid+8.8864; // adjust for normalization of prior //
zetgrid = lamgrid;
zetgrid[1] = 1E8;
zetgrid = zetgrid./(1+zetgrid);

/**** LOAD IRFS ****/

nvar = 5;
nirf = 40;
ti = seqa(1,1,40);

/** set lambda-grid **/
lamgrid  =  101 | 5 | 1 | 0.3 ;
nlambda = rows(lamgrid);

/** set Tind **/
lsamp = "T01";

/** initialize marginal data densities **/
irfgrid = zeros(nlambda,nvar^2*nirf);

/** iterate over lambda grid **/
lamind = 1;
do until lamind > nlambda;

   lambda = lamgrid[lamind,1];
   llam = "L" $+ ftos(90000+10*lambda,"%*.*lf",5,0);

   lpath  = resupath $+ "\\mhrun" $+ mhrun;
   lvarirf  = lpath $+ "\\" $+ llam $+ lsamp $+ "varirf0s";

   open fhvarirf = ^lvarirf for read; 

   varirf_m     = readr(fhvarirf,1);
   varirf_s     = readr(fhvarirf,1);
   varirf_hpd_l = readr(fhvarirf,1);
   varirf_hpd_h = readr(fhvarirf,1);
   varirf_med   = readr(fhvarirf,1);

   irfgrid[lamind,.] = varirf_med;

   closeall;
   
   lamind = lamind+1;
   
endo;

/* Plot Impulse Response functions
** All responses are to target inflation shock
*/

titlestr = "Target Inflation"  $|
           "Output"            $|
           "Inflation"         $|
           "Interest Rates"    $|
           "Money Balances";


drawtics = ( 0 ~ 0.4 ~ 0.2 )|
           ( -0.2 ~ 0.1 ~ 0.1 )|
           ( 0 ~ 0.4 ~ 0.2 )|
           ( 0 ~ 0.4 ~ 0.2 )|
           ( -1 ~ 0 ~ 0.5 );
           
graphset;
begwind;
margin(0,0,0.2,0.2);
window(3,2,0);
fonts("microb");
_ptitlht = 0.4;
_paxht = 0.4;
_pnumht = 0.3;
_pltype = {6 1 3 4};
_pcolor = {1 0 2 4};
_protate = 0; 
_plctrl = 0;
_plwidth = 6.5;
_psymsiz = 5;
_protate = 0;

/* plot mdd first */

//xtics(0,1,0.2,1);
ytics(-975,-825,75,2);

ylabel("ln p(Y)");
xlabel("Lambda/(1+Lambda)");
xy(zetgrid,mddgrid); 

nextwind;

/* plot IRFs */

xlabel("Period");

pl_convvec = 5 | 1 | 2 | 3 | 4;

pl_ind = 1;
do until pl_ind > nvar;

   varirf_plot = zeros(nirf,nlambda);
  
   pl_sel = pl_convvec[pl_ind];

   lamind = 1;
   do until lamind > nlambda;

      varirf_med   = reshape(irfgrid[lamind,.],nvar^2,nirf)';
      varirf_plot[.,lamind] =varirf_med[.,pl_sel]; 
      
      lamind = lamind+1;

   endo;

   ytics(drawtics[pl_sel,1],drawtics[pl_sel,2],drawtics[pl_sel,3],2);
   ylabel(titlestr[pl_sel]);
   xy(ti,varirf_plot);
   nextwind;

   pl_ind = pl_ind+1;

endo;

endwind;
