/* filename:    dsgeirf.g
** description: The program computes impulse response 
**              functions for the DSGE model
** created:     11/06/01
*/

/********************************************************
** Open files with Parameter Draws
*/

llam = "L" $+ ftos(90000+10*lambda,"%*.*lf",5,0);

if Tind < 10;
   lsamp = "0" $+ ftos(Tind,"%*.*lf",1,0);
else;
   lsamp = ftos(Tind,"%*.*lf",2,0);
endif;

lsamp = "T" $+ lsamp;

/******************************************************************
**         Load Parameter Draws from MH Output
*/

lpath  = parapath $+ "\\mhrun" $+ mhrun;
lpara  = lpath $+ "\\" $+ llam $+ lsamp $+ "pa"  ;

open fhpara = ^lpara for read;

/* Initialize Output files
*/
opath     = resupath $+ "\\mhrun" $+ mhrun;
chkdir    = chk_dir(opath);

odsgeirf    = opath $+ "\\" $+ llam $+ lsamp $+ "dsgeirf0";

create fhdsgeirf = ^odsgeirf with IRF, nvar^2*nirf, 8;

/* Initialization
*/ 

nblock  = 1000;
eofloop = 0;
loopct  = 1;

do until eofloop; 

   /* Read blocks of size nsim
   */
   parasim = readr( fhpara, nblock );
   nread   = rows(parasim);
   npara   = cols(parasim);
   
   /** use every nuse-th draw **/
   indseq  = seqa(1,1,nread);
   indseq  = indseq % nuse;
   indseq  = indseq .NE 0;

   parasim = delif(parasim,indseq);

   if ismiss(parasim) == 1;
      eofloop = 1;
      goto loopdone;
   endif;

   nread      = rows(parasim);
   irfsim     = zeros(nread,nvar^2*nirf);



   "";
   "Loop      " loopct;
   "Blocksize " nread;
   eofloop = eof(fhpara);

   irfsim = zeros(nread,nvar^2*nirf);
   
   j = 1;
   do until j > rows(parasim);
   
      if fmod(j,nread/10)==0;".";; pause(1e-20); endif;
   
      impind = nvar;
      do until impind < 1;
      
         impact = zeros(nvar,1);
         impact[impind] = parasim[j,20+impind];
         
         yyirf = dsgeirf(parasim[j,.]',msel,nirf,impact);
         
         irfsim[j,1+(nvar-impind)*nvar*nirf:(nvar-impind+1)*nvar*nirf] = vec(yyirf)';
         
         impind = impind-1;
      
      endo;
      
         
      j = j+1;
  endo;
      
  /* Write Output
  */
  wr = writer(fhdsgeirf,irfsim);

  loopct = loopct + 1;

  loopdone:

endo;

closeall fhpara, fhdsgeirf;

/********************************************************************
**   Procedure to compute Impulse Response Function
********************************************************************/
proc (1) = dsgeirf(para,msel,nirf,imp);
local TT,QQ,RR,HH,DD,ZZ,VV,RC,QQ2, ssirf, yyirf, t;

/**********************************************************
**      System matrices for State-space
**********************************************************/

{TT,QQ,RR,HH,DD,ZZ,VV,RC,QQ2}=sysmat(para,msel);

ssirf = zeros(nirf,cols(ZZ));
yyirf = zeros(nirf,rows(ZZ));

ssirf[1,.] = (RR*imp)';
yyirf[1,.] = ssirf[1,.]*ZZ';
t = 2;
do until t > nirf;
   ssirf[t,.] = (TT*ssirf[t-1,.]')';
   yyirf[t,.] = ssirf[t,.]*ZZ';
   t = t+1;
endo;

eofirf:

/* Convert velocity response into real money balance
** response
*/
yyirf[.,5] = yyirf[.,5]+yyirf[.,2];

retp(yyirf);
endp;
