/* filename:    vardraw.g
** description: The program generates draws from the VAR
**              conditional on the DSGE model draws
** created:     11/06/01
*/

/********************************************************
** Open files with Parameter Draws
*/

llam = "L" $+ ftos(90000+10*lambda,"%*.*lf",5,0);

if Tind < 10;
   lsamp = "0" $+ ftos(Tind,"%*.*lf",1,0);
else;
   lsamp = ftos(Tind,"%*.*lf",2,0);
endif;

lsamp = "T" $+ lsamp;

/******************************************************************
**         Load Parameter Draws from MH Output
*/

lpath  = parapath $+ "\\mhrun" $+ mhrun;
lpara  = lpath $+ "\\" $+ llam $+ lsamp $+ "pa"  ;

open fhpara = ^lpara for read;

/* Define some Constants
*/
nvarpara  = nvar*(1+nvar*nlags) + nvar*(nvar+1)/2;

/* Initialize Output files
*/
opath  = parapath $+ "\\mhrun" $+ mhrun;
ovarpara  = opath $+ "\\" $+ llam $+ lsamp $+ "varpa"  ;

create fhvarpara = ^ovarpara with VARPARA, nvarpara, 8;

/* Initialization
*/ 

eofloop = 0;
loopct  = 1;

do until eofloop; 

   /* Read blocks of size nsim
   */
   parasim = readr( fhpara, nblock );
   nread   = rows(parasim);
   
   "";
   "Loop      " loopct;
   "Blocksize " nread;
   eofloop = eof(fhpara);
   lambda;
   
   varparasim = zeros(nread,nvarpara);
   
   /* compute Minnesota prior dummies (independent of theta)
   */
   {yyyym, xxyym, xxxxm, nobsm}   = varprior(nvar,nlags,1,hyp_,premom_); 
   
   j = 1;
   do until j > nread;
   
      if fmod(j,nread/10)==0;".";; pause(1e-20); endif;

      /* Compute DSGE model dummies
      */
      {yyyyd, xxyyd, xxxxd, retcode} = varprio(parasim[j,.]',msel);
      
      /* For each para, draw a CC and Sig for the VAR
      */
      if lambda < 101;
      
         yyyyc = yyyy + lambda*nobs*yyyyd + yyyym;
         xxyyc = xxyy + lambda*nobs*xxyyd + xxyym;
         xxxxc = xxxx + lambda*nobs*xxxxd + xxxxm;

         nobsc = nobs + nobs*lambda + nobsm;    
         k     = 1+nlags*nvar;
    
         /* Compute OLS estimates
         */
         CC_hat  = XXYYc/XXXXc;
         C_hat   = vec(CC_hat);
         SIG_hat = ( YYYYc -XXYYc'* ( XXYYc / XXXXc) )/nobsc;

         val = 0;
         do until val == 1;

           /* draw from the marginal posterior of SIG
           */
           H = nobsc*Sig_hat;
           Z = chol(inv(H))'*rndn(nvar,nobsc-k);
           Sig_sim = inv(Z*Z');

           /* draw from the conditional posterior of C
           */
           VC     = Sig_sim.*.inv(XXXXc);
           C_sim  = C_hat + cholpsd(VC)*rndn(nvar*k,1);
           CCt_sim= reshape(C_sim,nvar,k);

           /* Check for stationarity
           ** (last element of parameter vector is intercept)
           */
           /*
           if nlags == 1;
             CCtilde = CCt_sim[.,1:k-1];
           else;
             CCtilde = CCt_sim[.,1:k-1] |
                       (eye(nvar*(nlags-1)) ~ zeros(nvar*(nlags-1),nvar));
           endif;
           laCCtil = eig(CCtilde);
           if maxc(abs(laCCtil)) < 1.02; 
             val = 1;
           endif;
           */
           val = 1;

         endo; 

      else;
      
         CC_sim  = XXYYd/XXXXd;
         C_sim   = vec(CC_sim);
         SIG_sim = ( YYYYd -XXYYd'*( XXYYd / XXXXd ));
         
      endif;

      varparasim[j,.] = vec(C_sim)' ~ vech(Sig_sim)';
      
      j = j+1;
  endo;
      
  /* Write Output
  */
  wr = writer(fhvarpara,varparasim);

  loopct = loopct + 1;

endo;

closeall fhvarpara, fhpara;
