/* filename:    vardraw.g
** description: The program generates draws from the VAR
**              conditional on the DSGE model draws
** created:     11/06/01
*/

/********************************************************
** Open files with Parameter Draws
*/

llam = "L" $+ ftos(90000+10*lambda,"%*.*lf",5,0);

if Tind < 10;
   lsamp = "0" $+ ftos(Tind,"%*.*lf",1,0);
else;
   lsamp = ftos(Tind,"%*.*lf",2,0);
endif;

lsamp = "T" $+ lsamp;

/******************************************************************
**         Load Parameter Draws from MH Output
*/

lpath  = parapath $+ "\\mhrun" $+ mhrun;
lpara  = lpath $+ "\\" $+ llam $+ lsamp $+ "pa"  ;

open fhpara = ^lpara for read;

/* Define some Constants
*/
nvarpara  = nvar*(1+nvar*nlags) + nvar*(nvar+1)/2;

/* Initialize Output files
*/
opath  = parapath $+ "\\mhrun" $+ mhrun;
ovarpara  = opath $+ "\\" $+ llam $+ lsamp $+ "varpainf"  ;

create fhvarpara = ^ovarpara with VARPARA, nvarpara, 8;

/* Initialization
*/ 

eofloop = 0;
loopct  = 1;

do until eofloop; 

   /* Read blocks of size nsim
   */
   parasim = readr( fhpara, nblock );
   nread   = rows(parasim);

   "";
   "Loop      " loopct;
   "Blocksize " nread;
   eofloop = eof(fhpara);
   lambda;
   
   varparasim = zeros(nread,nvarpara);
   
   j = 1;
   do until j > rows(parasim);
   
      if fmod(j,nread/10)==0;".";; pause(1e-20); endif;

      /* For each para, draw a CC and Sig for the VAR
      */
      {yyyyd, xxyyd, xxxxd, retcode} = varprio(parasim[j,.]',msel);
      
      k     = 1+nlags*nvar;
    
      /* Compute OLS estimates
      */
      CC_hat  = XXYYd/XXXXd;
      C_hat   = vec(CC_hat);
      SIG_hat = ( YYYYd -XXYYd'*( XXYYd / XXXXd ));
      varparasim[j,.] = vec(C_hat)' ~ vech(Sig_hat)';
      
      j = j+1;
  endo;
      
  /* Write Output
  */
  wr = writer(fhvarpara,varparasim);

  loopct = loopct + 1;

endo;

closeall fhvarpara, fhpara;
