/* filename:    virf.g
** description: The program computes Cholesky IRFs
**              for the VAR 
** created:     11/06/01
*/

/********************************************************
** Open files with Parameter Draws
*/

llam = "L" $+ ftos(90000+10*lambda,"%*.*lf",5,0);

if Tind < 10;
   lsamp = "0" $+ ftos(Tind,"%*.*lf",1,0);
else;
   lsamp = ftos(Tind,"%*.*lf",2,0);
endif;

lsamp = "T" $+ lsamp;

/******************************************************************
**         Load Parameter Draws from MH Output
*/

lpath  = parapath $+ "\\mhrun" $+ mhrun;
lpara  = lpath $+ "\\" $+ llam $+ lsamp $+ "varpainf"  ;

open fhpara = ^lpara for read;

/* Define some Constants
*/
nvarpara  = nvar*(1+nvar*nlags) + nvar*(nvar+1)/2;

/* Initialize Output files
*/
opath     = resupath $+ "\\mhrun" $+ mhrun;
chkdir    = chk_dir(opath);

ovarirf    = opath $+ "\\" $+ llam $+ lsamp $+ "varirf0inf";

create fhvarirf = ^ovarirf with IRF, nvar^2*nirf, 8;


/* Initialization
*/ 
eofloop = 0;
loopct  = 1;
nsim    = 0;

do until eofloop; 

   /* Read blocks of size nread
   */
   varparasim = readr( fhpara, nblock );
   nread      = rows(varparasim);
   
   /** use every nuse-th draw **/
   indseq  = seqa(1,1,nread);
   indseq  = indseq % nuse;
   indseq  = indseq .NE 0;

   varparasim = delif(varparasim,indseq);

   if ismiss(varparasim) == 1;
      eofloop = 1;
      goto loopdone;
   endif;

   nread      = rows(varparasim);
   irfsim     = zeros(nread,nvar^2*nirf);

   "Loop      " loopct;
   "Blocksize " nread;
   eofloop = eof(fhpara);
   
   j = 1;
   do until j > nread;
   
      if fmod(j,nread/10)==0;".";; pause(1e-20); endif;

      /* Create Matrices CC and Sig
      */
      SIG_sim = xpnd(varparasim[j,nvar*(1+nvar*nlags)+1:nvarpara]');
      CCt_sim = reshape(varparasim[j,1:nvar*(1+nvar*nlags)]',nvar,1+nvar*nlags);
      CC_sim  = CCt_sim';
      SIG_chol = cholpsd(SIG_sim);
      
      /* Compute MA representation from companion form VAR
      */
      CCtilde =  CCt_sim[.,1:nlags*nvar] |
                (eye(nvar*(nlags-1)) ~ zeros(nvar*(nlags-1),nvar));

      CCpower = eye(nvar*nlags);
      Msel    = eye(nvar) | zeros((nlags-1)*nvar,nvar) ;
      
      BBsim       = zeros(nirf,nvar^2);
      BBsim[1,.]  = vec(Msel'*CCpower*Msel*SIG_chol)';
      
      if nirf > 1;
      
       t = 2;
       do until t > nirf;
      
         CCpower = CCtilde*CCpower;
         BBsim[t,.]  = vec(Msel'*CCpower*Msel*SIG_chol)';
         t = t+1;

       endo;
       
      endif;

      /* convert velocity response to first shock
      ** into real money balance response
      */
      BBsim[.,5] = BBsim[.,5]+BBsim[.,2];

      
      irfsim[j,.] = vec(BBsim)';           
                 
      j = j+1;
  endo;



  wr = writer(fhvarirf,irfsim);
  loopct = loopct + 1;

  loopdone:

endo;

closeall fhvarirf, fhpara;
