/* filename:    varprior.g
** created:     11/05/01
*/

proc(4) = varprio(para,msel);
/********************************************************************************* 
** Global nvar, nlags
**
** description: The program converts the cross moment matrices for the DSGE prior
*********************************************************************************/

local TT,QQ,RR,HH,DD,ZZ,VV,RC,QQ2,
      retcode,yyyyd,xxxxd,xxyyd,
      GAMM0,Pt,Ptr,nstate,
      l,r;

yyyyd = 0;
xxyyd = 0;
xxxxd = 0;

/**********************************************************
**      System matrices for State-space
**********************************************************/

{TT,QQ,RR,HH,DD,ZZ,VV,RC,QQ2}=sysmat(para,msel);

TT = TT .* (abs(TT) .> 1e-10);
RR = RR .* (abs(RR) .> 1e-10);

/**********************************************************
** Check determinacy 
**********************************************************/
if (RC[1] == 1) AND (RC[2]==1);
   /* determinacy */
   retcode = 1;

elseif (RC[1] == 1) AND (RC[2]==0) ;
   /* indeterminacy */
   retcode = 0;
   goto eofdsgeprio;

else;
   /* no equilibrium exists, numerical problems */
   retcode = 0;
   goto eofdsgeprio;

endif;


/**********************************************************
**  Compute nlags autocovariances to create E[XX], E[XY]
**  and E[YY]
**********************************************************/
nstate = rows(TT);

/* Initialize covariance matrix for y(t)
*/
GAMM0 = zeros( nvar*(nlags+1),nvar*(nlags+1) );

/* Initialize covariance matrix for s(t-p)
*/
Pt = zeros(nstate,nstate);
Pt[1:nstate-1,1:nstate-1] = dlyap(TT[1:nstate-1,1:nstate-1],RR[1:nstate-1,.]*QQ*RR[1:nstate-1,.]');
Pt[nstate,nstate] = 0.5;
Pt = Pt .* (abs(Pt) .> 1e-10);
Pt = 0.5*(Pt + Pt');

l = 1;
do until l > 40;
   Pt = TT*Pt*TT' + RR*QQ*RR';
   Pt = Pt .* (abs(Pt) .> 1e-10);
   Pt = 0.5*(Pt + Pt');
   l=l+1;
endo;


/* Fill in elements of GAMM0
*/
r = nlags+1;
do until r < 1;

   Pt = TT*Pt*TT' + RR*QQ*RR';
   Pt = Pt .* (abs(Pt) .> 1e-10);
   Pt = 0.5*(Pt + Pt');
   
   Ptr = Pt;
    
   l = r;
   do until l < 1;
   
      GAMM0[1+(l-1)*nvar:l*nvar , 1+(r-1)*nvar:r*nvar]
        = ZZ*Ptr*ZZ';
      GAMM0[1+(r-1)*nvar:r*nvar , 1+(l-1)*nvar:l*nvar]
        = ZZ*Ptr'*ZZ';
      Ptr = TT*Ptr;   
      l = l-1;
   endo;
   
   r = r-1;
endo; 

GAMM0 = GAMM0 .* (abs(GAMM0) .> 1e-10);
GAMM0 = 0.5*(GAMM0 + GAMM0');

/**********************************************************
**  Create limit cross product matrices
**  intercept appears last in VAR
**********************************************************/

yyyyd = GAMM0[1:nvar,1:nvar] + DD*DD';
     
/* start with yyxxd, then take transpose  */
xxyyd = zeros(nvar,nvar*nlags+1);
l = 1;
do until l > nlags;
   xxyyd[.,nvar*(l-1)+1:nvar*l] = GAMM0[1:nvar,1+l*nvar:(l+1)*nvar] + DD*DD';
   l = l+1;
endo;
xxyyd[.,nvar*nlags+1] = DD;
xxyyd = xxyyd';
     
xxxxd = zeros(1+nlags*nvar,1+nlags*nvar);
xxxxd[nlags*nvar+1,nlags*nvar+1] = 1;
xxxxd[nlags*nvar+1,1:nlags*nvar] = ones(1,nlags).*.DD';
xxxxd[1:nlags*nvar,nlags*nvar+1] = ones(nlags,1).*.DD;
     
r = 1;
do until r>nlags;
     l = r;
     do until l>nlags;
        xxxxd[nvar*(r-1)+1:nvar*r , nvar*(l-1)+1:nvar*l ] 
             = GAMM0[1+r*nvar:(r+1)*nvar,1+l*nvar:(l+1)*nvar] + DD*DD';
        xxxxd[nvar*(l-1)+1:nvar*l , nvar*(r-1)+1:nvar*r ] 
             = GAMM0[1+l*nvar:(l+1)*nvar,1+r*nvar:(r+1)*nvar] + DD*DD';
        l = l+1;
     endo;
     r = r+1;
endo;
     
eofdsgeprio:
     
retp(yyyyd,xxyyd,xxxxd,retcode);
endp;

/***************************************************************
The procedure for generating Minnesota dummy observations  
****************************************************************/ 

proc(4) = varprior(nv,nlag,nex,hyp,premom); 
/* nv: number of variables
** nlag: number of lags
** nex: number of exogenous variables including intercept
** hyp: vector of hyperparameters
** premom: presample moments - mean | stdd
** XX = [ lags ] [constant]
*/

local tau, dd, ww, lam, mm, xdu, ydu, yxdu,
      breakss, dsize, j, sig,lammean, mumean, 
      lamall, muall,
      yyyym, xxxxm, xxyym;   

tau = hyp[1,.];  
dd  = hyp[2,.]; 
ww  = hyp[3,.]; 
lam = hyp[4,.]; 
mm  = hyp[5,.]; 

/* initializations */
dsize   =   nex+(nlag+ww+1)*nv;       
breakss =   zeros(5,1); 
ydu     =   zeros(dsize,nv); 
xdu     =   zeros(dsize,nv*nlag+nex); 

/* Dummies for the coefficients of the first lag
*/ 
sig          =   diagrv(zeros(nv,nv),premom[2,.]');  
ydu[1:nv,.]  =   tau*sig;
xdu[1:nv,.]  =   (tau*sig)~zeros(nv,(nlag-1)*nv+nex);
breakss[1]   =   nv; 

/* Dummies for the coefficients of the remaining lags 
*/
if nlag > 1;
   ydu[breakss[1]+1:nv*nlag,.] = zeros((nlag-1)*nv,nv);
   j = 1;
   do until j > nlag - 1; 
     xdu[breakss[1]+(j-1)*nv+1:breakss[1]+j*nv,.] 
         = zeros(nv,j*nv) ~ tau*sig*((j+1)^dd) ~ zeros(nv,(nlag-1-j)*nv+nex);  
     j = j+1; 
   endo; 
   breakss[2] = breakss[1]+(nlag-1)*nv;   
else;
   breakss[2]=breakss[1]; 
endif;

/* Dummies for the covariance matrix of error terms 
*/ 
ydu[breakss[2]+1:breakss[2]+ww*nv,.] = ones(ww,1).*.sig; 
breakss[3] = breakss[2]+ww*nv; 

/* Dummies for the coefficients of the constant term
*/ 
lammean             = lam*premom[1,.];
ydu[breakss[3]+1,.] = lammean; 
xdu[breakss[3]+1,.] = (ones(1,nlag) .*. lammean) ~ lam; 
breakss[4]          = breakss[3]+1; 

/* Dummies for the covariance matrix of coefficients of different lags 
*/ 
mumean = diagrv(zeros(nv,nv),(mm*premom[1,.])');
ydu[breakss[4]+1:breakss[4]+nv,.]
  = mumean; 
xdu[breakss[4]+1:breakss[4]+nv,.]  
  = (ones(1,nlag) .*. mumean) ~ zeros(nv,nex);
breakss[5] = breakss[4]+nv; 

yyyym = ydu'*ydu;
xxxxm = xdu'*xdu;
xxyym = xdu'*ydu;

retp(yyyym,xxyym,xxxxm,dsize); 
endp; 

     

proc(1) = marglh(para,msel,lambda);
/***************************************************************************
**     global
**     yyyy, xxxx, xxyy, nobs,
**     nlags, nvar,
**
**     Compute marginal likelihood
***************************************************************************/

local yyyyd, xxxxd, xxyyd,
      yyyyc, xxxxc, xxyyc,
      yyyym, xxxxm, xxyym, nobsm,
      yyyydm, xxxxdm, xxyydm, nobsdm,
      retcode,
      k, pyt, pytdm, nobsc, lnkapt, lnkaptdm,
      SIG_tilde, SIG_stard, SIG_stardm, PHI_star, i;

/* Compute cross product matrices for DSGE dummy observations
*/
{yyyyd, xxyyd, xxxxd, retcode} = varprio(para,msel);

/* Compute cross product matrices for Minnesota dummy observations
*/
{yyyym, xxyym, xxxxm, nobsm} =  varprior(nvar,nlags,1,hyp_,premom_); 

if retcode == 0;
    pYT = -1E10;
    pYTdm = -1E-10;
    goto eodsgepost;
endif;

if lambda < 101;

    /* Combine Dummy Observations
    */
    yyyydm = lambda*nobs*yyyyd + yyyym;
    xxyydm = lambda*nobs*xxyyd + xxyym;
    xxxxdm = lambda*nobs*xxxxd + xxxxm;     
    nobsdm = lambda*nobs + nobsm;

    /* Combine Dummy Observations
    ** and actuals
    */
    yyyyc = yyyy + yyyydm;
    xxyyc = xxyy + xxyydm;
    xxxxc = xxxx + xxxxdm;
    
    nobsc = nobs + nobsdm;    
    k     = 1+nlags*nvar;
    
    /* Compute OLS estimates for dummy observations
    */
    SIG_stardm = ( YYYYdm -XXYYdm'*( XXYYdm / XXXXdm ) ); 
    
    lnkaptdm = 0.5*nvar*(nobsdm-k)*ln(2);
    i = 1;
    do until i > nvar;
       lnkaptdm = lnkaptdm + lngam(0.5*(nobsdm-k+1-i));
       i=i+1;
    endo;
            
    pYtdm  = lnkaptdm  - 0.5*(nobsdm-k)*ln(det(Sig_stardm)) 
           - 0.5*nvar*ln(det(XXXXdm));

    /* Compute OLS estimates for actual and dummy observations
    */
    SIG_tilde = ( YYYYc -XXYYc'*( XXYYc / XXXXc) );
    
    lnkapt = -0.5*nobs*nvar*ln(2*pi) + 0.5*nvar*(nobsc-k)*ln(2);
    i = 1;
    do until i > nvar;
       lnkapt = lnkapt + lngam(0.5*(nobsc-k+1-i));
       i = i+1;
    endo;
            
    pYt  = lnkapt  - 0.5*(nobsc-k)*ln(det(Sig_tilde)) - 0.5*nvar*ln(det(XXXXc)) - pYtdm;

else;

    /* Compute OLS estimates for dummy observations
    */
    SIG_stard = ( YYYYd -XXYYd'*( XXYYd / XXXXd ) );
    PHI_star  = XXYYd/XXXXd;
            
    pyt = -0.5*nobs*nvar*ln(2*pi) - 0.5*nobs*ln(det(SIG_stard))
          -0.5*sumc(diag(inv(SIG_stard)*(yyyy - xxyy'*PHI_star - PHI_star'*xxyy + PHI_star'*xxxx*PHI_star)));          
    
endif;
    
eodsgepost:
    
retp(pYt);
endp;
