/* filename:    bmargmh.g
** description: posterior mode batch
** created:     11/05/01
*/

new;
/** set seed **/
/** rndseed 1234; **/

/********************************************************
* House cleaning and set defaults
********************************************************/
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
__output = 1;       /** 1 for verbose of CSMIN**/
__graph  = 1;       /** 1 for graph mode **/
_verbose = 2;       /** 0 for silence, 1 for compact, 2 for detailed**/
_fcmptol = 1E-10;

/** only the following 2 lines are model dependent **/
#include dsge_mod.src;
#include dsge_para.src;
#include dsge_spec.g;
#include var_spec.g;

#include pathspec.g;

/** start log file **/
outstr = resupath $+ "\\" $+ ftos(timedt,"%*.*lf",1,0) $+ "mh.log";
output file = ^outstr reset;

/********************************************************
* Configure the Metropolis algorithm
********************************************************/

mhrun   = "1";

nblocks = 100;
nsim    = 1000;

cc0     = 0.51;
cc      = 0.3;  
/* 
** use cc = 0.15 for usm11t0p1
*/

appendmode = 0;

if appendmode ne 1;

  "-----------------------------------------------------------";
  "Creating new output files";
  "Press Key to Continue";
  "-----------------------------------------------------------";
  k = keyw;
  "";

else;

  /*******************************
  ** open existing output files
  *******************************/

  "-----------------------------------------------------------";
  "Opening Existing Output Files";
  "Press Key to Continue";
  "-----------------------------------------------------------";

  k = keyw;
  "";

endif;


/********************************************************
*  Import prior specification
********************************************************/
priorfile = prioname $+ ".txt";
load path = ^priopath prior[] = ^priorfile;
prior = reshape(prior,rows(prior)/5,5);

{prior,para_names} = psel(prior,msel);

npara    = rows(prior);
pshape   = prior[.,1];
pmean    = prior[.,2];
pstdd    = prior[.,3];
pmask    = prior[.,4];
pfix     = prior[.,5];
pmaskinv = 1-pmask;
pshape   = pshape.*pmaskinv;

/** parameter specification: transformation and bounds **/
_trspec      = prtr(msel);
_trspec[.,1] = _trspec[.,1].*pmaskinv;
_bounds      = _trspec[.,2 3];


/******************************************************** 
** Iterate over lambda
*/

Tind = 1;
do until Tind > 1;

   /********************************************************
   * Import data series
   ********************************************************/
   #include loaddata.g;
   #include var_loaddata.g; 

   lamind = 1;
   do until lamind > rows(lamgrid);

      lambda = lamgrid[lamind];
      gosub runproc;

      lamind = lamind+1;

   endo;

   Tind = Tind+1;  

endo;

/** close log file **/
output file = ^outstr off;

end;

runproc:

"";
"";
"";
"=========================================================";
"Index L,T" lamind Tind;
"LAMBDA = " lambda;
"---------------------------------------------------------";

#include p_margmh.g

return;


#include p_varprior.g;
