/* filename:    dsgeirf.g
** description: The program computes impulse response 
**              functions for the DSGE model
** created:     11/06/01
*/

new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  __output = 1;
  _fcmptol = 1E-10;
  _verbose = 1;           /** 1 for verbose **/

#include dsge_mod.src;
#include dsge_para.src;
#include dsge_spec.g;
#include pathspec.g;


/********************************************************************
* Load Parameter Draws from MH Output
********************************************************************/
mhrun  = "1";    /* "0" for draws from prior; "1" for draws from posterior */
nblock = 10000;   /* block size */
nuse   = 10;      /* use every nuse observation */

lpath  = parapath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;
chkdir = chk_dir(opath);

lpara  = lpath $+ "\\pa";

open fhpara = ^lpara for read;

/* Initialize Output files
*/
opath     = resupath $+ "\\mhrun" $+ mhrun;
chkdir    = chk_dir(opath);

odsgeirf    = opath $+ "\\dsgeirf";

create fhdsgeirf = ^odsgeirf with IRF, nvar^2*nirf, 8;

/* Initialization
*/ 

/* nblock  = 10000; */
eofloop = 0;
loopct  = 1;

"Generating IRFs...";

do until eofloop; 

   /** Read blocks of size nblock **/
   parasim = readr(fhpara,nblock);
   nread   = rows(parasim);
   npara   = cols(parasim);

   /** use every nuse-th draw **/
   indseq  = seqa(1,1,nread);
   indseq  = indseq % nuse;
   indseq  = indseq .ne 0;

   parasim = delif(parasim,indseq);
   nread   = rows(parasim);

   if ismiss(parasim) == 0;

   " ";
   "Loop      " loopct;
   "Blocksize " nread;
   eofloop = eof(fhpara);

   irfsim = zeros(nread,nvar^2*nirf);
   
   j = 1;
   do until j > rows(parasim);
   
      if fmod(j,nread/10)==0;".";; pause(1e-20); endif;
   
      impind = 1;
      do until impind > nvar;
      
         impact = zeros(nvar,1);
         impact[impind] = parasim[j,20+impind];
         
         yyirf = dsgeirf(parasim[j,.]',msel,nirf,impact);
         
         irfsim[j,1+(impind-1)*nvar*nirf:impind*nvar*nirf] = vec(yyirf)';
         
         impind = impind+1;
      
      endo;
      
         
      j = j+1;
  endo;
      
  /* Write Output
  */
  wr = writer(fhdsgeirf,irfsim);

  endif;

  loopct = loopct + 1;
  eofloop = eof(fhpara);


endo;

closeall fhpara, fhdsgeirf;

"DONE";

/********************************************************************
**   Procedure to compute Impulse Response Function
********************************************************************/
proc (1) = dsgeirf(para,msel,nirf,imp);
local TT,QQ,RR,HH,DD,ZZ,VV,RC,QQ2, ssirf, yyirf, t;

/**********************************************************
**      System matrices for State-space
**********************************************************/

/* fix the MD elasticity */
// para[10] = 3;

{TT,QQ,RR,HH,DD,ZZ,VV,RC,QQ2}=sysmat(para,msel);

/* manual adjustment: turn inverse velocity into real money
** balances:
*/
ZZ[4,17]=0; 


ssirf = zeros(nirf,cols(ZZ));
yyirf = zeros(nirf,rows(ZZ));

ssirf[1,.] = (RR*imp)';
yyirf[1,.] = ssirf[1,.]*ZZ';
t = 2;
do until t > nirf;
   ssirf[t,.] = (TT*ssirf[t-1,.]')';
   yyirf[t,.] = ssirf[t,.]*ZZ';
   t = t+1;
endo;

eofirf:

retp(yyirf);
endp;
