/******************************************************************************
* DSGE_SS.G
* for every draw of DSGE parameters, computes steady state values of variables 
*
* created:  03-SEP-2007
* based on: dsge_ac.g
******************************************************************************/
new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  __output = 1;
  _fcmptol = 1E-10;
  _verbose = 1;           /** 1 for verbose **/

#include dsge_mod.src;
#include dsge_para.src;
#include dsge_spec.g;
#include pathspec.g;

/********************************************************************
* Load Parameter Draws from MH Output
********************************************************************/
mhrun  = "2";
nblock = 10000;    /* block size */
nuse   = 10;      /* use every nuse observation */

lpath  = parapath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;
chkdir = chk_dir(opath);

lpara       = lpath $+ "\\pa";
open fhpara = ^lpara for read;

/** set dimensions **/
n_paratr = 4;

/** Initialize Output files **/
oparatr = opath $+ "\\paratr";

create fhparatr = ^oparatr with PARAtr, n_paratr, 8;

/** Initialization **/
eofloop = 0;
loopct  = 1;

if _verbose;
   "";
   "Calculating steady states...";
   "----------------------------";
endif;

do until eofloop;

   if _verbose;
      "";
      "Block           " ftos(loopct,"%*.*lf",6,0);
   endif;

   /** Read blocks of size nblock **/
   parasim = readr(fhpara,nblock);
   nread   = rows(parasim);

   /** use every nuse-th draw **/
   indseq  = seqa(1,1,nread);
   indseq  = indseq % nuse;
   indseq  = indseq .NE 0;

   parasim = delif(parasim,indseq);
   nread   = rows(parasim);

   if ismiss(parasim) == 0;

      paratrsim = zeros(nread, n_paratr);

      j = 1;
      do until j > nread;

         para = parasim[j,.]';

         /* compute steady states */
         {sst, valid} = dsgess(para,msel);

         Rst = sst[4];
         Dst = sst[11];

         /* parameter transformations */
         
         lam    = para[3];
         zeta   = para[6];
         nu     = para[10];
         iota   = para[11];
         rr_steady = para[19];
         beta   = 1/(1+rr_steady/400);

         pc_lag   = iota/(1+beta*iota);
         pc_slope = (1-zeta)*(1-zeta*beta)/( zeta*(1+beta*iota));
         md_elasticity = 1/( nu*(Rst-1) );
         nk_distort = 100*(1-1/Dst);

         paratrsim[j,.] = pc_slope~pc_lag~md_elasticity~nk_distort;         
            
         if _verbose;
            if fmod(j,nread/10)==0; ".";; pause(1e-20);endif;
         endif;
         j = j+1;

      endo;

      /** write Output **/
      wr = writer(fhparatr,paratrsim);

   endif;

   if _verbose;
      "";
      "Draws Processed " ftos(rows(paratrsim),"%*.*lf",6,0);
        "";
   endif;

   loopct = loopct + 1;
   eofloop = eof(fhpara);

endo;

closeall fhpara, fhparatr;

end;


