/* filename:    fig_paratrdens.g
** description: Plot prior and posterior densities:
**              
*/

new;
closeall;
library user, pgraph;
cls;
outwidth 128;

/******************************************************************
**         Load Density Estimates
*/
#include dsge_mod.src;
#include dsge_para.src;
#include dsge_spec.g;
#include pathspec.g;

         
ngrid_   = 100;

paratrnames = "NKPC Marg. Cost Coeff" $|
              "NKPC Lagged Infl. Coeff" $|
              "Money Demand Elasticity" $|
              "NK Distortion" ; 
  
/* load density estimates
*/
model_id =  "\\m1_t2m11t2p3\\results\\mhrun1\\paratrdens";
densmat = zeros(ngrid_,1);
ldens = workpath $+ model_id;
open fhdens = ^ldens for read;
densmat = densmat~readr(fhdens,ngrid_);
closeall fhdens;

densmatpost = densmat[.,2:cols(densmat)];
drawdim = cols(densmat);

/* load density estimates
*/
model_id =  "\\m1_t2m11t2p3\\results\\mhrun1prior\\paratrdens";
densmat = zeros(ngrid_,1);
ldens = workpath $+ model_id;
open fhdens = ^ldens for read;
densmat = densmat~readr(fhdens,ngrid_);
closeall fhdens;

densmatprior = densmat[.,2:cols(densmat)];
drawdim = cols(densmat);


/* Load gridrange for density evaluation
*/
gridfile = "paratrgrid.out";
load path=^priopath gridrange[drawdim,2] = ^gridfile;

graphset;
fonts("microb");
_ptitlht = 0.4;
_paxht = 0.4;
_pnumht = 0.4;
/*
_pltype = {1 1 3 3 6 6 4}; 
_pcolor = {4 4 1 1 2 2 6};
*/
_pltype = {6 1 3 6 }; 
_pcolor = {2 4 1 2 };

/* _plegstr = "Prior\000Posterior"; 
_plegctl = {2 4 4 4}; */
_plwidth = 10;

yticsmat = ( 0 ~ 20 ~ 5 )|
           ( 0 ~ 15 ~ 5 )|
           ( 0 ~ 1.5 ~ 0.5 )|
           ( 0 ~ 2.5 ~ 0.5 );

xticsmat = ( 0 ~ 0.5 ~ .25 )|
           ( 0 ~ 0.5 ~ .25 )|
           ( 0 ~ 5 ~ 2.5 )|
           ( 0 ~ 2 ~ 1 );


begwind;
window(2,2,0);

jvec = 1 | 2 | 4 | 3;

plotind = 1;
do until plotind > 4;

   j = jvec[plotind];  

   /* Compute Grid for density evaluation */
   paragrid = seqa(gridrange[j,1],(gridrange[j,2]-gridrange[j,1])/(ngrid_-1),ngrid_);

   ytics(yticsmat[j,1],yticsmat[j,2],yticsmat[j,3],2); 
   xtics(xticsmat[j,1],xticsmat[j,2],xticsmat[j,3],2); 


   title(paratrnames[j]);
   xy(paragrid,densmatpost[.,j]~densmatprior[.,j]);
   nextwind;

   "Generated Graph" plotind "out of" drawdim;
   pause(1e-5);
   
   plotind = plotind+1;
   
   clear drawcol;
   
endo;

endwind;

end;

