/*************************************************************
** filename:    fig_paratrhpd.g
** description: plots confidence set, hpd set, and identified set
*************************************************************/

new;
closeall;
/********************************************************
* House cleaning and set defaults
********************************************************/
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
_verbose = 1;       /** 1 for verbose **/

#include dsge_mod.src;
#include dsge_para.src;
#include dsge_spec.g;
#include pathspec.g;

dirstr = "\\mhrun1\\paratrHPD2dim";

/********************************************************
**  Load Upper and lower bounds of sets 
********************************************************/

linput       = resupath $+ dirstr $+ "90"  ;
open fhinput = ^linput for read;
HPD90_mat      = readr( fhinput, 3); 
HPD90_mat      = HPD90_mat';
closeall fhinput;

/********************************************************
**  Load other estimates 
********************************************************/

/* Load gridrange for density evaluation
*/
nkpcfile = "nkpc.txt";
load path=^datapath nkpc_hat[42,3] = ^nkpcfile;
nkpc_hat = nkpc_hat[.,2 1];

/********************************************************
* Generate Plots
********************************************************/

graphset;
begwind;
margin(0.2,0.2,0.2,0.2); 

window(1,1,0);
fonts("microb");
_plwidth = 8;
_psymsiz = 3;
_plctrl  =  0;
_ptitlht = 0.2;
_paxht   = 0.2;
_pnumht  = 0.2;

xlabel("NKPC Marg. Cost Coeff");
ylabel("NKPC Lagged Infl. Coeff");

xtics(0,1,0.25,1);
ytics(-0.25,0.75,0.25,1);

_pcolor = {2 2};
_pltype = {6 6};

xy(HPD90_mat[.,1],HPD90_mat[.,2:3]);

_pcolor = {4 2};
_psymsiz = 4;
_plctrl = -1;
_pstype = 11;

xy(nkpc_hat[.,1],nkpc_hat[.,2]);


endwind;

end;
