/* filename:    fig_wcinfl.g
** description: The program plots the 
**              the Welfare costs associated to different inflation **              rate targets (benchmark is an annual rate of 2.5%)  
** created:     11/06/01
*/

new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  _verbose = 1;           /** 1 for verbose **/

#include dsge_spec.g;
#include pathspec.g;

/******************************************************************
**         Load Welfare Costs summaries
*/


/* Read Posterior Summary File
*/
lwfcosts = workpath $+ "\\m1_t2m11t2p3\\results\\mhrun1\\wfcosts";
open fhwfcosts = ^lwfcosts for read;

welfarecosts      = readr(fhwfcosts',1);
welfarecostsci    = readr(fhwfcosts',2);
inflationtarget   = readr(fhwfcosts',1);
zeroline          = zeros(41, 1);
closeall fhwfcosts;

/* Read some welfare cost trajectories
*/
ntraj = 10;
lpath           = resupath $+ "\\mhrun1";
ldraw           = lpath $+ "\\" $+ "wfcosts_draws"; 
open fhdraw     = ^ldraw for read;

ntotal = 5000;
nblock = floor(ntotal/ntraj);

welfarecoststraj = zeros(ntraj,cols(welfarecosts));

trajind = 1;
do until trajind > ntraj; 

   drawblock = readr( fhdraw, nblock );
   welfarecoststraj[trajind,.] = 100*drawblock[1,.];
   trajind = trajind + 1;

endo;
closeall fhdraw;

/* Ordering
** variables: Welfare Costs (y-axis), inflation target (x-axis) */

titlestr = "Welfare Costs of Deviating from 2.5% Inflation Target";

ystr     = "Welfare Costs (% of Consumption)";
xstr     = "Inflation Target (%)";

              
graphset;
begwind;
margin(0,0,0.2,0.2);
window(1,2,0);
fonts("microb");
_ptitlht = 0.2;
_paxht = 0.4;
_pnumht = 0.4;
_protate = 0; 
_plctrl = 0;
_psymsiz = 5;
_protate = 0;
/* _plegstr = "Money-Search\000MIU"; */
/* _plegctl = 1;  legend appears in the right-lower corner of page */ 
/* _plegctl = { 2 5 4.5 4.0 }; */

/* title(titlestr); */
ylabel(ystr);
xlabel(xstr); 
ytics(-0.4,0.2,0.1,2);
//ytics( -3, 1, 1, 2); 

xtics(-2,3,1,1);

_plwidth = 4;
_pltype = {6 6 6 6 6 6 6 6 6 6 1 6 6 6 6 6};
_pcolor = {2 2 2 2 2 2 2 2 2 2 1 2 2 2 2 2};
xy(inflationtarget',welfarecoststraj'~zeroline);
nextwind;

_plwidth = 8;
_pltype = {6 3 3 1};
_pcolor = {2 4 4 1};
xy(inflationtarget', welfarecosts'~welfarecostsci'~zeroline);  
endwind;
