/* filename:    paratrdens.g
** description: Computes posterior density estimates 
**              based on the output of the posterior simulator
*/

/******************************************************************************/
new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  __output = 1;
  _fcmptol = 1E-10;
  _verbose = 1;           /** 1 for verbose **/

#include dsge_mod.src;
#include dsge_para.src;
#include dsge_spec.g;
#include pathspec.g;

/* load Parameter Draws from MH Output
*/
mhrun  = "1";
nblock = 10000;    /* block size */
nburn  = 101;  
ngrid_ = 100;

lpath  = resupath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;

ldraw  = lpath $+ "\\paratr";
odens  = opath $+ "\\paratrdens";

open fhdraw = ^ldraw for read;

drawrow = readr( fhdraw, nburn); 
drawdim = cols(drawrow);
drawrow = seekr( fhdraw, nburn);

/* Load gridrange for density evaluation
*/
gridfile = "paratrgrid.out";
load path=^priopath gridrange[drawdim,2] = ^gridfile;

/* initialize matrix with density
** estimates
*/
densmat = zeros(ngrid_,drawdim);

j = 1;
do until j > drawdim;

   "Processing column" j;
   pause(1e-5);

   /* Read only the j'th column
   */
   drawrow   = seekr( fhdraw, nburn); 
   drawblock = readr( fhdraw, 1);

   drawcol = drawblock[1,j];
   eofloop = 0;
   ndraws  = 1;
   
   do until eofloop; 

         drawblock = readr( fhdraw, nblock );
         drawcol   = drawcol | drawblock[.,j];
         ndraws    = ndraws + rows(drawblock);
         eofloop   = eof(fhdraw);
         
   endo;

   /* Compute SD for bandwidth selection */
   drawstdd = stdc(drawcol);
   drawstdd;
   
   /* Compute Grid for density evaluation */
   paragrid = seqa(gridrange[j,1],(gridrange[j,2]-gridrange[j,1])/(ngrid_-1),ngrid_);
   
   if drawstdd > 0;    
      
      /* Construct density estimate */
      h    = 10*1.06*ndraws^(-1/5)*drawstdd;
      densmat[.,j] = densest(paragrid,drawcol,h);      
      
   endif;   
     
   j = j+1;

endo;
clear drawcol;

/* Save the results
*/

create fhdens = ^odens with PARA, drawdim, 8;
wr = writer(fhdens, densmat );
closeall fhdraw, fhdens; 

"Saved Density Estimates";

end;

/**************************************************************/
/*                         Procedures                         */
/**************************************************************/


proc (1) = densest(paragrid,draws,h);
/* This procedure computes a simple kernel density estimate
*/
local   ndraws, npt, pdfhat, i;

ndraws = rows(draws);
npt    = rows(paragrid);
pdfhat = zeros(npt,1); 

i = 1;
do until i > npt;
   pdfhat[i] = 1/(ndraws*h)*sumc( pdfn( (ones(ndraws,1)*paragrid[i]-draws)/h ) );
   i = i+1;
endo;

retp(pdfhat);
endp;