/* filename:    irfplot.g
** description: The program plots the 
**              the DSGE impulse response functions
** created:     11/06/01
*/


new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  _verbose = 1;           /** 1 for verbose **/

//#include pathspec.g;


/******************************************************************
**         Load IRF summaries
*/
workpath  = cdir(0);
ldsgeirf1 = workpath $+    "\\..\\miu\\m1_t2m11t2p3\\results\\mhrun1\\dsgeirfs";
lvarirf   = workpath $+    "\\m1_t2vmt2p1\\results\\mhrun1\\varirfs";

nresp = 11;
nvar  = 5;
nirf  = 40;
nirfplot = 20;
ti    = seqa(1,1,nirf);

/* Read Posterior Simulation Summary File:
** DSGE model: responses of several variables to all shocks
** Variables: "Real GDP", "Inflation", "CM Output", "DM Output", "Real Money", 
**            "DM/CM Price", "Nom. Interest";
** Shocks: 
** 1 = government spending
** 2 = money demand
** 3 = policy (short run)
** 4 = technology
** 5 = policy (long run)
*/


/* DSGE 1 
** for MIU: use nresp = 5, don't reorder 
*/

open fhdsgeirf = ^ldsgeirf1 for read;

nresp = 5;

dsgeirf_m     = readr(fhdsgeirf,1);
dsgeirf_s     = readr(fhdsgeirf,1);
dsgeirf_hpd_l = readr(fhdsgeirf,1);
dsgeirf_hpd_h = readr(fhdsgeirf,1);

dsgeirf_m     = reshape(dsgeirf_m,nvar*nresp,nirf)';
dsgeirf_hpd_l = reshape(dsgeirf_hpd_l,nvar*nresp,nirf)';
dsgeirf_hpd_h = reshape(dsgeirf_hpd_h,nvar*nresp,nirf)';

shsel = 5;

/* Re-order responses
** 1) "Real GDP"
** 2) "Agg. Inflation" $|
** 3) "CM Output" $|
** 4) "DM Output" $|
** 5) "DM Inflation" $|
** 6) "DM/CM Rel. Price" $|
** 7) "Nom. Interest" $|
** 8) "Real Money"    $|
** 9) "Target Inflation" $|
** 10)"CM Inflation" $|           
** 11)"Inverse Velocity";
*/

irfindx    = (shsel-1)*nresp;
y_ind      = irfindx + 1;
pi_ind     = irfindx + 2;
velo_ind   = irfindx + 11;
R_ind      = irfindx + 7;
pistar_ind = irfindx + 9;

/* for MIU use the following
*/
y_ind      = irfindx + 1;
pi_ind     = irfindx + 2;
velo_ind   = irfindx + 4;
R_ind      = irfindx + 3;
pistar_ind = irfindx + 5;

dsge1irf_m     = dsgeirf_m[.,y_ind pi_ind R_ind velo_ind pistar_ind];
dsge1irf_hpd_l = dsgeirf_hpd_l[.,y_ind pi_ind R_ind velo_ind pistar_ind];
dsge1irf_hpd_h = dsgeirf_hpd_h[.,y_ind pi_ind R_ind velo_ind pistar_ind];

closeall;

/* Read Posterior Simulation Summary File:
** VAR: 
** Variables: "Real GDP", "Inflation", "Nom. Interest", "Real Money", "Target Inflation"
**
** Shocks: 
** 1 = policy (long run)
*/

open fhvarirf = ^lvarirf for read;

varirf_m     = readr(fhvarirf,1);
varirf_s     = readr(fhvarirf,1);
varirf_hpd_l = readr(fhvarirf,1);
varirf_hpd_h = readr(fhvarirf,1);

varirf_m     = reshape(varirf_m,nvar,nirf)';
varirf_hpd_l = reshape(varirf_hpd_l,nvar,nirf)';
varirf_hpd_h = reshape(varirf_hpd_h,nvar,nirf)';

/* eliminate target inflation response
*/
/*
varirf_m     = varirf_m[.,1:nvar-1];
varirf_hpd_l = varirf_hpd_l[.,1:nvar-1];
varirf_hpd_h = varirf_hpd_h[.,1:nvar-1];
*/

closeall;

/* Plot Impulse Response functions
*/

titlestr = "Real GDP" $|
           "Inflation" $|
           "Interest Rate" $|
           "Inverse Velocity" $|
           "Target Inflation" ;

drawtics = ( -0.5 ~ 0.5 ~ 0.5 )  |
           (  0   ~ 0.5 ~ 0.25  )  |
           (  -0.5 ~ 0.5 ~ 0.5  )  |
           ( -2   ~ 1   ~ 1     )  |
           (  0   ~ 0.5 ~ 0.25   )  ;
          
graphset;
begwind;
margin(0,0,0.2,0.2);
window(2,2,0);
fonts("microb");
_ptitlht = 0.3;
_paxht = 0.3;
_pnumht = 0.3;

_pltype = {6 6 3 3};
_pcolor = {1 1 4 4};

/*
_pltype = {6 1 3 3};
_pcolor = {1 6 4 4};
*/

/*
_pltype = {6 6 3 3};
_pcolor = {1 1 4 4};
*/
_protate = 0; 
_plctrl = 0;
_plwidth = 6.5;
_psymsiz = 5;
_protate = 0;
/* _plegstr = "DSGE\000VAR"; */

pl_ind = 1;
do until pl_ind > 4;

   title(titlestr[pl_ind]);
   ytics(drawtics[pl_ind,1],drawtics[pl_ind,2],drawtics[pl_ind,3],1); 
   xtics(0,20,5,5);

   /*
   xy(ti[1:nirfplot],  dsge1irf_m[1:nirfplot,pl_ind] ~ dsge2irf_m[1:nirfplot,pl_ind]
         ~ varirf_hpd_l[1:nirfplot,pl_ind]  ~ varirf_hpd_h[1:nirfplot,pl_ind] );
   */

   xy(ti[1:nirfplot],  dsge1irf_hpd_l[1:nirfplot,pl_ind] ~ dsge1irf_hpd_h[1:nirfplot,pl_ind]
         ~ varirf_hpd_l[1:nirfplot,pl_ind]  ~ varirf_hpd_h[1:nirfplot,pl_ind] );

         
   nextwind;
   
   /*
   $titlestr[pl_ind];
   ti~dsgeirf1_m[.,pl_ind]~dsgeirf1_hpd_l[.,pl_ind]~dsgeirf1_hpd_h[.,pl_ind];
   "==================";
   "";
   */
               
   pl_ind = pl_ind+1;
endo;
    
endwind;
