/* filename:    vm_irf.g
** description: The program computes impulse response 
**              functions for the VAR model
** created:     11/06/01
*/

new;
closeall;
library pgraph, user;
cls;
outwidth 256;

format /mat /on /mb1 /ros 16,8;

/** Global defaults **/
  __output = 1;
  _fcmptol = 1E-10;
  _verbose = 1;           /** 1 for verbose **/

#include vm_spec.g; 
#include pathspec.g;

/********************************************************************
* Load Parameter Draws from Posterior Sampler Output
********************************************************************/
mhrun  = "1";    /* "0" for draws from prior; "1" for draws from posterior */
nblock = 10000;  /* block size */
nuse   = 1;      /* use every nuse observation */

lpath  = parapath $+ "\\mhrun" $+ mhrun;
opath  = resupath $+ "\\mhrun" $+ mhrun;
chkdir = chk_dir(opath);

lpara1  = lpath $+ "\\paravar1";
lpara2  = lpath $+ "\\paravar2";

open fhpara1 = ^lpara1 for read;
open fhpara2 = ^lpara2 for read;

/* Initialize Output files
*/
opath     = resupath $+ "\\mhrun" $+ mhrun;
chkdir    = chk_dir(opath);

ovarirf   = opath $+ "\\varirf";

create fhvarirf = ^ovarirf with IRF, nvar_*nirf, 8;

/* Initialization
*/ 
eofloop = 0;
loopct  = 1;
k = 2+nlags_*nvar_;

"Generating IRFs...";

do until eofloop; 

   /** Read blocks of size nblock **/
   parasim1 = readr(fhpara1,nblock);
   parasim2 = readr(fhpara2,nblock);
   nread    = rows(parasim1);
   npara1   = cols(parasim1);

   /** use every nuse-th draw **/
   indseq  = seqa(1,1,nread);
   indseq  = indseq % nuse;
   indseq  = indseq .ne 0;

   parasim1 = delif(parasim1,indseq);
   parasim2 = delif(parasim2,indseq);
   nread    = rows(parasim1);

   if ismiss(parasim1) == 0;

   " ";
   "Loop      " loopct;
   "Blocksize " nread;
   eofloop = eof(fhpara1);

   irfsim = zeros(nread,nvar_*nirf);
   
   j = 1;
   do until j > rows(parasim1);
   
      if fmod(j,nread/10)==0;".";; pause(1e-20); endif;
   
      phi = reshape(parasim1[j,1:(nvar_-1)*k],nvar_-1,k)';
      sigma22 = parasim2[j,.];

      YYirf = varirf(Phi,Sigma22,nirf);

      irfsim[j,.] = vec(YYirf)';
         
      j = j+1;
  endo;
      
  /* Write Output
  */
  wr = writer(fhvarirf,irfsim);

  endif;

  loopct = loopct + 1;

endo;

closeall;

"";
"DONE";
end;

/********************************************************************
**   Procedure to compute Impulse Response Function
********************************************************************/
proc (1) = varirf(Phi,Sigma22,nirf);
local nvar, nlags, phi_irf, phi_target, imp, YYirf, XXpred, j;

nvar  = cols(Phi)+1;
nlags = (rows(Phi)-2)/nvar;

/* remove intercept and target-diff
*/
phi_irf = phi[1:nvar*nlags,.];

/* add target inflation eq
*/
if nlags == 1;
   phi_target = (0|0|0|0|1);
else;
   phi_target = (  (0|0|0|0|1) 
                 | zeros( nvar*(nlags-1), 1) );
endif;

phi_irf = phi_irf ~ phi_target;

/* create impact for inflation target shock
*/
imp = sqrt(sigma22)*( phi[nvar*nlags+1,.]~1 );

/* compute impulse responses
*/
YYirf  = zeros(nirf,nvar);
XXpred = zeros(1,nvar*nlags);

j = 1;
do until j > nirf;

   if j == 1;
      YYirf[j,.] = XXpred*phi_irf + imp;
   else;
      YYirf[j,.] = XXpred*phi_irf;
   endif;
   
   if nlags > 1;
      XXpred[nvar+1:nvar*nlags] = XXpred[1:(nlags-1)*nvar];
   endif;
   XXpred[1:nvar] = YYirf[j,.];
   
   j = j+1;
   
endo;

retp(YYirf);
endp;

